---
filters:
  - interlinks.lua
interlinks:
  autolink: true
  aliases:
    quartodoc: null
  #sources:
  #  test:
  #    url: https://example.com
---

* `some_func`
* `some_func()`
* `some_func(a=1)`
* `some_func()`{.qd-no-link}
* `some_func + some_func`
* `a.b.c`
* `~a.b.c`
* `a.b.c()`
* `quartodoc.Auto()`
* `Auto()`